@@ -1,10 +1,24 @@
+#### 
+#rm(list=ls())
+#library(lavaan)
+#data("PDII",package="influence.SEM")
+#model <- "
+# F1 =~ y1+y2+y3+y4
+#"
+#data <- PDII
+#scaled <- FALSE
+
 Deltachi <-
 function(model,data,...,scaled=FALSE) {
   fit0 <- sem(model, data, ...)
-  
   LPT <- parTable(fit0)
   var.idx <- which(LPT$op=="~~" & LPT$lhs==LPT$rhs)
   
+  has.tcltk <- require("tcltk")
+  if (has.tcltk) 
+    pb <- tkProgressBar("", "Inspecting case ", 
+                        0, nrow(data))
+  
   if (scaled) {
     Chi0 <- inspect(fit0,"fit")["chisq.scaled"]
   } else {
@@ -12,6 +26,11 @@ function(model,data,...,scaled=FALSE) {
   }
   Dchi <- NULL
   for (i in 1:nrow(data)) {
+    
+    if (has.tcltk) 
+      setTkProgressBar(pb, i, label = 
+                        sprintf(paste("Inspecting case", i,"of",nrow(data))))
+    
     fit <- try(sem(model,data[-i,],...),TRUE)
     
     if (class(fit)=="try-error") {
@@ -29,5 +48,10 @@ function(model,data,...,scaled=FALSE) {
       }
     }
   } 
+  
+  if (has.tcltk) close(pb)
   return(Dchi)  
 }
+
+#fit0 <- sem(model,data=PDII)
+#Deltachi(model,data=PDII)
\ No newline at end of file
